@@ -75,8 +75,6 @@ def token_to_wei(amount, market):
         decimals = consts.DECIMALS_USDC
     elif market == consts.MARKET_DAI:
         decimals = consts.DECIMALS_DAI
-    elif market == consts.MARKET_PBTC:
-        decimals = consts.DECIMALS_PBTC
     else:
         raise ValueError('Invalid market')
     return int(amount * (10 ** decimals))
@@ -86,6 +84,14 @@ def btc_to_sats(amount):
     return amount * (10 ** consts.DECIMALS_PBTC)
 
 
+def usd_to_order_amount(amount):
+    return amount * (10 ** consts.DECIMALS_USDC)
+
+
+def link_to_order_amount(amount):
+    return amount * (10 ** consts.DECIMALS_PLINK)
+
+
 def pair_to_base_quote_markets(pair):
     if pair == consts.PAIR_WETH_DAI:
         return (consts.MARKET_WETH, consts.MARKET_DAI)
@@ -95,6 +101,10 @@ def pair_to_base_quote_markets(pair):
         return (consts.MARKET_DAI, consts.MARKET_USDC)
     elif pair == consts.PAIR_PBTC_USDC:
         return (consts.MARKET_PBTC, consts.MARKET_USDC)
+    elif pair == consts.PAIR_WETH_PUSD:
+        return (consts.MARKET_WETH, consts.MARKET_PUSD)
+    elif pair == consts.PAIR_PLINK_USDC:
+        return (consts.MARKET_PLINK, consts.MARKET_USDC)
     raise ValueError('Invalid pair')
 
 
@@ -106,33 +116,6 @@ def get_is_buy(side):
     raise ValueError('Invalid side')
 
 
-def get_limit_fee(base_market, amount, postOnly):
-    if postOnly:
-        if base_market == consts.MARKET_PBTC:
-            if (amount < consts.SMALL_TRADE_SIZE_PBTC):
-                return consts.FEE_ZERO
-            else:
-                return consts.FEE_MAKER_PBTC
-        else:
-            return consts.FEE_ZERO
-    if base_market == consts.MARKET_WETH:
-        if (amount < consts.SMALL_TRADE_SIZE_WETH):
-            return consts.FEE_SMALL_WETH
-        else:
-            return consts.FEE_LARGE_WETH
-    elif base_market == consts.MARKET_DAI:
-        if (amount < consts.SMALL_TRADE_SIZE_DAI):
-            return consts.FEE_SMALL_DAI
-        else:
-            return consts.FEE_LARGE_DAI
-    elif base_market == consts.MARKET_PBTC:
-        if (amount < consts.SMALL_TRADE_SIZE_PBTC):
-            return consts.FEE_SMALL_PBTC
-        else:
-            return consts.FEE_LARGE_PBTC
-    raise ValueError('Invalid base_market')
-
-
 def decimalToStr(d):
     return '{:f}'.format(d.normalize())
 
